/*
 * Copyright (C) 2002 Robert Ernst <robert.ernst@linux-solutions.at>
 *
 * This file may be distributed and/or modified under the terms of the
 * GNU General Public License version 2 as published by the Free Software
 * Foundation and appearing in the file LICENSE.GPL included in the
 * packaging of this file.
 *
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See COPYING for GPL licensing information.
 *
 */

#ifndef __MAHJONGG_HEADER__
#define __MAHJONGG_HEADER__

#include <qpe/qpemenubar.h>
#include <qmainwindow.h>
#include <qpopupmenu.h>
#include "Board.h"
#include "Status.h"
#include "ScoreMng.h"


#define CATEGORY_NUM 5
#define MENU_ID_MAX  9

class Mahjongg : public QMainWindow
{
    Q_OBJECT

public:
    Mahjongg(QWidget *parent = 0, const char *name = 0, WFlags f = 0);
    ~Mahjongg();

private:
    void readConfig(void);
    void writeConfig(void);
    void initHiScoreMng();
    void deleteHiScoreMng();
    void registHiScoreData( CScoreMng *pScoreMng );
    void disableItems(void);

private:
    Board *m_board;
    CStatus *m_Status;
    QPopupMenu *m_gameMenu;
    QPopupMenu *m_layoutMenu;
    int m_layout;
    CScoreMng  *m_pScoreMng[CATEGORY_NUM];
    int m_idMenu[MENU_ID_MAX];

protected slots:
    void updateLayout(int layout);
    void start(void);
    void hint(void);
    void undo(void);
    void redo(void);
    void enableItems(void);
    void gameOver(void);
    void showScore(void);
    void giveup(void);
};

#endif // __MAHJONGG_HEADER__

