/*
 * Copyright (C) 2002 Robert Ernst <robert.ernst@linux-solutions.at>
 *
 * This file may be distributed and/or modified under the terms of the
 * GNU General Public License version 2 as published by the Free Software
 * Foundation and appearing in the file LICENSE.GPL included in the
 * packaging of this file.
 *
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See COPYING for GPL licensing information.
 *
 */

#include <qwidget.h>
#include <qpixmap.h>
#include <qbitmap.h>
#include <qimage.h>
#include <qpainter.h>
#include <qapplication.h>
#include "SpriteCollection.h"
#include "images/data.c"
#include "config.h"

#define BOOT_LOGOSTRING "PRESENTS"
#define COPYLIGHT1 "(C) Taiga Yonekura 2006"
#define COPYLIGHT2 "This program is distributed under terms of"
#define COPYLIGHT3 "the GNU General Public License(GPL)."

SpriteCollection::SpriteCollection(QWidget *parent)
{
    m_parent = parent;
    m_tile[0].loadFromData(img_0_data_, sizeof (img_0_data_));
    m_tile[1].loadFromData(img_1_data_, sizeof (img_1_data_));
    m_tile[2].loadFromData(img_2_data_, sizeof (img_2_data_));
    m_tile[3].loadFromData(img_3_data_, sizeof (img_3_data_));
    m_tile[4].loadFromData(img_4_data_, sizeof (img_4_data_));
    m_tile[5].loadFromData(img_5_data_, sizeof (img_5_data_));
    m_tile[6].loadFromData(img_6_data_, sizeof (img_6_data_));
    m_tile[7].loadFromData(img_7_data_, sizeof (img_7_data_));
    m_tile[8].loadFromData(img_8_data_, sizeof (img_8_data_));
    m_tile[9].loadFromData(img_9_data_, sizeof (img_9_data_));
    m_tile[10].loadFromData(img_10_data_, sizeof (img_10_data_));
    m_tile[11].loadFromData(img_11_data_, sizeof (img_11_data_));
    m_tile[12].loadFromData(img_12_data_, sizeof (img_12_data_));
    m_tile[13].loadFromData(img_13_data_, sizeof (img_13_data_));
    m_tile[14].loadFromData(img_14_data_, sizeof (img_14_data_));
    m_tile[15].loadFromData(img_15_data_, sizeof (img_15_data_));
    m_tile[16].loadFromData(img_16_data_, sizeof (img_16_data_));
    m_tile[17].loadFromData(img_17_data_, sizeof (img_17_data_));
    m_tile[18].loadFromData(img_18_data_, sizeof (img_18_data_));
    m_tile[19].loadFromData(img_19_data_, sizeof (img_19_data_));
    m_tile[20].loadFromData(img_20_data_, sizeof (img_20_data_));
    m_tile[21].loadFromData(img_21_data_, sizeof (img_21_data_));
    m_tile[22].loadFromData(img_22_data_, sizeof (img_22_data_));
    m_tile[23].loadFromData(img_23_data_, sizeof (img_23_data_));
    m_tile[24].loadFromData(img_24_data_, sizeof (img_24_data_));
    m_tile[25].loadFromData(img_25_data_, sizeof (img_25_data_));
    m_tile[26].loadFromData(img_26_data_, sizeof (img_26_data_));
    m_tile[27].loadFromData(img_27_data_, sizeof (img_27_data_));
    m_tile[28].loadFromData(img_28_data_, sizeof (img_28_data_));
    m_tile[29].loadFromData(img_29_data_, sizeof (img_29_data_));
    m_tile[30].loadFromData(img_30_data_, sizeof (img_30_data_));
    m_tile[31].loadFromData(img_31_data_, sizeof (img_31_data_));
    m_tile[32].loadFromData(img_32_data_, sizeof (img_32_data_));
    m_tile[33].loadFromData(img_33_data_, sizeof (img_33_data_));
    m_tile[34].loadFromData(img_34_data_, sizeof (img_34_data_));
    m_tile[35].loadFromData(img_35_data_, sizeof (img_35_data_));
    m_tile[36].loadFromData(img_36_data_, sizeof (img_36_data_));
    m_tile[37].loadFromData(img_37_data_, sizeof (img_37_data_));
    m_tile[38].loadFromData(img_38_data_, sizeof (img_38_data_));
    m_tile[39].loadFromData(img_39_data_, sizeof (img_39_data_));
    m_tile[40].loadFromData(img_40_data_, sizeof (img_40_data_));
    m_tile[41].loadFromData(img_41_data_, sizeof (img_41_data_));
    m_tile[42].loadFromData(img_42_data_, sizeof (img_42_data_));
    m_tile[43].loadFromData(img_43_data_, sizeof (img_43_data_));
    m_tile[44].loadFromData(img_44_data_, sizeof (img_44_data_));
    m_background = new QPixmap;
    m_background->loadFromData(background_data_, sizeof (background_data_));

    m_shade = new QPixmap;
    m_shade->loadFromData(shade_data_, sizeof (shade_data_));

    m_logo[0].loadFromData(jankey_data_, sizeof (jankey_data_));
    m_logo[1].loadFromData(tdev_data_, sizeof (tdev_data_));
    m_title[0].loadFromData(mobile_data_, sizeof (mobile_data_));
    m_title[1].loadFromData(title_data_, sizeof (title_data_));
}

void SpriteCollection::drawTile(QPainter &painter, int x, int y, int which)
{
    if (which >= 0 && which <= 44) {
	painter.drawPixmap(x, y, m_tile[which]);
    }
}

QPixmap *SpriteCollection::backgroundPixmap(void)
{
    return m_background;
}

QPixmap *SpriteCollection::tilePixmap(int which)
{
    if (which >= 0 && which <= 44) {
	return &m_tile[which];
    } else {
	return m_background;
    }
}

int SpriteCollection::tileWidth(void)
{
  return TILE_W;
}

int SpriteCollection::tileHeight(void)
{
    return TILE_H;
}

QPixmap *SpriteCollection::shadePixmap(void)
{
    return m_shade;
}
void SpriteCollection::drawBoot(QPainter &paint, int width, int height)
{
  QColor white( 220, 220, 220 );
  QColor black(0,0,0);
  QString str = BOOT_LOGOSTRING;

  paint.fillRect( 0, 0, width, height, white );
  paint.drawPixmap( center_x(&m_logo[0]), BOOT_LOGO1_Y, m_logo[0] );
  paint.drawPixmap( center_x(&m_logo[1]), BOOT_LOGO2_Y, m_logo[1] );

  paint.setPen(black);
  paint.drawText( center_x(&str), BOOT_LOGOSTRING_Y, str );
  
}

void SpriteCollection::drawTitle(QPainter &paint, int width, int height)
{
  QColor white( 255, 255, 255 );
  QColor strColor( 0, 0, 0 );
  QString str;
  int x,y;
  int i,w,h;
  int which;

  w = tileWidth();
  h = tileHeight();
  paint.fillRect( 0, 0, width, height, white );

  x = 0; 
  y = 0;
  i = 0;
  which = 0;
  while(y+i/12*h < SCREENH*2/3){
    if(  which > 36 ){
      which = 0;
    }
    paint.drawPixmap(x+(i%12)*w, y+i/12*h, m_tile[which]);
    paint.drawPixmap(x+(i%12)*w, y+i/12*h, *m_shade);
    i++;
    which++;
  }

  paint.drawPixmap( center_x(&m_title[0]), TITLE_LOGO_POSY, m_title[0] );
  paint.drawPixmap( center_x(&m_title[1]), TITLE_POSY, m_title[1] );

  paint.setPen(strColor);
  str = COPYLIGHT1;
  paint.drawText( center_x(&str), COPYLIGHT1_POSY, str );
  str = COPYLIGHT2;
  paint.drawText( center_x(&str), COPYLIGHT2_POSY, str );
  str = COPYLIGHT3;
  paint.drawText( center_x(&str), COPYLIGHT3_POSY, str );

}
int SpriteCollection::center_x(QPixmap* pImg)
{
  int length = pImg->width();
  return (SCREENW/2-length/2);
}

int SpriteCollection::center_x(QString *pStr )
{
  QFont f = QApplication::font();
  QFontMetrics fm = QFontMetrics(f);
  int length = fm.width(*pStr);

  return (SCREENW/2-length/2);
}
